summaryrefslogtreecommitdiff
path: root/staging
diff options
context:
space:
mode:
Diffstat (limited to 'staging')
-rw-r--r--staging/cli.c4
-rw-r--r--staging/mz.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/staging/mz.h b/staging/mz.h
index cad091f..d9ac716 100644
--- a/staging/mz.h
+++ b/staging/mz.h
@@ -79,7 +79,7 @@ static inline void verbose_l2(const char *format, ...)
// "Dies ist ein schrecklicher Ort."
-#define MZ_DEFAULT_CONFIG_PATH "/etc/mausezahn/" // see also mz_default_config_path below
+#define MZ_DEFAULT_CONFIG_PATH "/etc/netsniff-ng/" // see also mz_default_config_path below
#define MZ_DEFAULT_LOG_PATH "/var/log/mausezahn/" // see also mz_default_log_path below
#define SLEEP usleep // The sleep function to use. Consider 'nanosleep' in future.
diff --git a/staging/cli.c b/staging/cli.c
index 0e22640..ad040a1 100644
--- a/staging/cli.c
+++ b/staging/cli.c
@@ -27,13 +27,13 @@ void mz_cli_init()
{
amp_head = automops_init();
// Initialize default credentials (will be overwritten by mz.cfg)
strcpy(mz_username, MZ_DEFAULT_USERNAME);
strcpy(mz_password, MZ_DEFAULT_PASSWORD);
strcpy(mz_enable, MZ_DEFAULT_ENABLE_PASSWORD);
// read login credentials from config file
- if (cli_read_cfg("mz.cfg")) {
+ if (cli_read_cfg("mausezahn.cfg")) {
fprintf(stderr, "mz: Problems opening config file. Will use defaults\n");
}
@@ -27,13 +27,13 @@ void mz_cli_init()
{
amp_head = automops_init();
- // Initialize default credentials (will be overwritten by mz.cfg)
+ // Initialize default credentials (will be overwritten by mausezahn.cfg)
strcpy(mz_username, MZ_DEFAULT_USERNAME);
strcpy(mz_password, MZ_DEFAULT_PASSWORD);